@@ -101,7 +101,7 @@ func main() {
 			}
 			if u := plugin.GetURL(name); u != "" {
 				//nolint:stylecheck // this is a top level error - capitalization is ok
-				return fmt.Errorf("The plugin %q is not it in your system.\nDownload it from %s", name, u)
+				return fmt.Errorf("The plugin %q was not found on this system.\nDownload it from %s", name, u)
 			}
 			return cli.ShowCommandHelp(ctx, name)
 		}
