@@ -6,10 +6,10 @@ import (
 	"text/tabwriter"
 
 	adminAPI "github.com/smallstep/certificates/authority/admin/api"
-	"github.com/smallstep/cli/errs"
 	"github.com/smallstep/cli/flags"
 	"github.com/smallstep/cli/utils/cautils"
 	"github.com/urfave/cli"
+	"go.step.sm/cli-utils/errs"
 	"go.step.sm/linkedca"
 )
 
@@ -18,10 +18,10 @@ func addCommand() cli.Command {
 		Name:   "add",
 		Action: cli.ActionFunc(addAction),
 		Usage:  "add an admin to the CA configuration",
-		UsageText: `**step beta ca admin add** <subject> <provisioner> [**--super**]
-[**--admin-cert**=<file>] [**--admin-key**=<file>]
-[**--admin-provisioner**=<string>] [**--admin-subject**=<string>]
-[**--password-file**=<file>] [**--ca-url**=<uri>] [**--root**=<file>]`,
+		UsageText: `**step ca admin add** <subject> <provisioner> [**--super**]
+[**--admin-cert**=<file>] [**--admin-key**=<file>] [**--admin-subject**=<subject>]
+[**--admin-provisioner**=<name>] [**--admin-password-file**=<file>]
+[**--ca-url**=<uri>] [**--root**=<file>] [**--context**=<name>]`,
 		Flags: []cli.Flag{
 			cli.BoolFlag{
 				Name:  "super",
@@ -29,13 +29,14 @@ func addCommand() cli.Command {
 			},
 			flags.AdminCert,
 			flags.AdminKey,
-			flags.AdminProvisioner,
 			flags.AdminSubject,
-			flags.PasswordFile,
+			flags.AdminProvisioner,
+			flags.AdminPasswordFile,
 			flags.CaURL,
 			flags.Root,
+			flags.Context,
 		},
-		Description: `**step beta ca admin add** adds an admin to the CA configuration.
+		Description: `**step ca admin add** adds an admin to the CA configuration.
 
 ## POSITIONAL ARGUMENTS
 
@@ -49,12 +50,12 @@ func addCommand() cli.Command {
 
 Add regular Admin:
 '''
-$ step beta ca admin add max@smallstep.com google
+$ step ca admin add max@smallstep.com google
 '''
 
 Add SuperAdmin:
 '''
-$ step beta ca admin add max@smallstep.com google --super
+$ step ca admin add max@smallstep.com google --super
 '''
 `,
 	}
