@@ -92,8 +92,8 @@ func newCaConfigClient(ctx context.Context, cfg *config.Config, cfgFile string)
 		}
 	}
 	a, err := authority.New(cfg, authority.WithAdminDB(newNoDB()),
-		//nolint:staticcheck // TODO: WithProvisioners has been deprecated, temporarily do not lint this line.
-		authority.WithSkipInit(), authority.WithProvisioners(provClxn))
+		authority.WithSkipInit(), authority.WithProvisioners(provClxn)) //nolint:staticcheck // TODO: WithProvisioners has been deprecated, temporarily do not lint this line.
+
 	if err != nil {
 		return nil, errors.Wrapf(err, "error loading authority")
 	}
