@@ -239,34 +239,34 @@ func signAction(ctx *cli.Context) error {
 	jwks := ctx.String("jwks")
 	kid := ctx.String("kid")
 	var isX5C bool
-	if len(x5cCertFile) > 0 {
+	if x5cCertFile != "" {
 		if x5cKeyFile == "" {
 			return errs.RequiredWithOrFlag(ctx, "x5c-cert", "key", "x5c-key")
 		}
-		if len(x5tCertFile) > 0 {
+		if x5tCertFile != "" {
 			return errs.MutuallyExclusiveFlags(ctx, "x5c-cert", "x5t-cert")
 		}
 		if ctx.IsSet("jwk") {
 			return errs.MutuallyExclusiveFlags(ctx, "x5c-cert", "jwk")
 		}
-		if len(jwks) > 0 {
+		if jwks != "" {
 			return errs.MutuallyExclusiveFlags(ctx, "x5c-cert", "jwks")
 		}
 		isX5C = true
 	}
 
 	var isX5T bool
-	if len(x5tCertFile) > 0 {
+	if x5tCertFile != "" {
 		if x5tKeyFile == "" {
 			return errs.RequiredWithOrFlag(ctx, "x5t-cert", "key", "x5t-key")
 		}
-		if len(x5cCertFile) > 0 {
+		if x5cCertFile != "" {
 			return errs.MutuallyExclusiveFlags(ctx, "x5t-cert", "x5c-cert")
 		}
 		if ctx.IsSet("jwk") {
 			return errs.MutuallyExclusiveFlags(ctx, "x5t-cert", "jwk")
 		}
-		if len(jwks) > 0 {
+		if jwks != "" {
 			return errs.MutuallyExclusiveFlags(ctx, "x5t-cert", "jwks")
 		}
 		isX5T = true
@@ -289,16 +289,16 @@ func signAction(ctx *cli.Context) error {
 	// Add parse options
 	var options []jose.Option
 	options = append(options, jose.WithUse("sig"))
-	if len(alg) > 0 {
+	if alg != "" {
 		options = append(options, jose.WithAlg(alg))
 	}
-	if len(kid) > 0 {
+	if kid != "" {
 		options = append(options, jose.WithKid(kid))
 	}
 	if isSubtle {
 		options = append(options, jose.WithSubtle(true))
 	}
-	if passwordFile := ctx.String("password-file"); len(passwordFile) > 0 {
+	if passwordFile := ctx.String("password-file"); passwordFile != "" {
 		options = append(options, jose.WithPasswordFile(passwordFile))
 	}
 
