@@ -104,7 +104,7 @@ func verifyAction(ctx *cli.Context) error {
 
 		secret = otpKey.Secret()
 		// period query param
-		if periodStr := q.Get("period"); len(periodStr) > 0 {
+		if periodStr := q.Get("period"); periodStr != "" {
 			period64, err := strconv.ParseUint(periodStr, 10, 0)
 			if err != nil {
 				return errors.Wrap(err, "error parsing period from url")
@@ -112,7 +112,7 @@ func verifyAction(ctx *cli.Context) error {
 			period = uint(period64)
 		}
 		// digits query param
-		if digitStr := q.Get("digits"); len(digitStr) > 0 {
+		if digitStr := q.Get("digits"); digitStr != "" {
 			digits64, err := strconv.ParseInt(digitStr, 10, 0)
 			if err != nil {
 				return errors.Wrap(err, "error parsing period from url")
@@ -121,7 +121,7 @@ func verifyAction(ctx *cli.Context) error {
 		}
 		// algorithm query param
 		algFromQuery := q.Get("algorithm")
-		if len(algFromQuery) > 0 {
+		if algFromQuery != "" {
 			algStr = algFromQuery
 		}
 	}
